TwitterClient class

Constructors

TwitterClient()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

favoriteTweet(int id) → void
followUser(int id) → void
getMentions() → Future<List<Tweet>?>
getProfile() → Future<User?>
getReplies(String query, int sinceId, [int maxId = -1]) → Future<List<Tweet>?>
getTimeline() → Future<List<Tweet>?>
getTweet(int id) → Future<Tweet?>
getUser(String? tag) → Future<User?>
getUserTimeline(String tag) → Future<List<Tweet>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reply(String status, int replyId) → void
retweet(int id) → void
searchTweets(String query, [dynamic count = 200]) → Future<List<Tweet>?>
searchUsers(String query, [dynamic count = 100]) → Future<List<User>?>
toString() → String
A string representation of this object.
inherited
tweet(String status) → void
tweetMedia(String status, String mediaIds) → void
tweetPromo(String status) → Future<Map?>
tweetResponse(String status) → Future<bool>
undoRetweet(int id) → void
unfavoriteTweet(int id) → void
unfollowUser(int id) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

twitter ↔ TwitterSession?
getter/setter pair

Static Methods

generateSignature(String method, String base, List<String> sortedItems) → String
setKeys(String consumerKey, String secretKey) → void